@@ -3,8 +3,9 @@ Main interface for ecs service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ecs import (
+    from mypy_boto3_ecs import (
         Client,
         ECSClient,
         ListAccountSettingsPaginator,
@@ -19,7 +20,7 @@ Usage::
         ServicesStableWaiter,
         TasksRunningWaiter,
         TasksStoppedWaiter,
-        )
+    )
 
     session = boto3.Session()
 
@@ -39,9 +40,10 @@ Usage::
     list_task_definition_families_paginator: ListTaskDefinitionFamiliesPaginator = client.get_paginator("list_task_definition_families")
     list_task_definitions_paginator: ListTaskDefinitionsPaginator = client.get_paginator("list_task_definitions")
     list_tasks_paginator: ListTasksPaginator = client.get_paginator("list_tasks")
+    ```
 """
-from mypy_boto3_ecs.client import ECSClient, ECSClient as Client
-from mypy_boto3_ecs.paginator import (
+from .client import ECSClient
+from .paginator import (
     ListAccountSettingsPaginator,
     ListAttributesPaginator,
     ListClustersPaginator,
@@ -51,13 +53,15 @@ from mypy_boto3_ecs.paginator import (
     ListTaskDefinitionsPaginator,
     ListTasksPaginator,
 )
-from mypy_boto3_ecs.waiter import (
+from .waiter import (
     ServicesInactiveWaiter,
     ServicesStableWaiter,
     TasksRunningWaiter,
     TasksStoppedWaiter,
 )
 
+Client = ECSClient
+
 
 __all__ = (
     "Client",
